% This code implements does some of the basic processing to the data done
% in Angrist and Evans (1998). This is ran and the output saved before any
% of the inference procedures are implemetned.

clear;

% Load the data and keep some of the basic variables we need
load m_d_806.mat;

Nfull = size(st_dataset,1);                     % Length of the entire dataset

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Process some of the variables before saving dataset %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% First: Construct the twin instruments. Back out necessary variables
ageq2nd = ConvertCell(st_dataset.ageq2nd);      
ageq3rd = ConvertCell(st_dataset.ageq3rd);      

% Build the instrument
multi2nd = zeros(Nfull,1);                      % Preallocate variable     
multi2nd(ageq2nd == ageq3rd) = 1;               % Say twins if 2nd and 3rd same age

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Second: Check for illegitimate kids. Back out necessary variables
qtrmar = st_dataset.qtrmar;                     
qtrbthm = st_dataset.qtrbthm;                   
yobm = st_dataset.yobm;                         
agemar = st_dataset.agemar;                     
yobk = st_dataset.yobk;                         
qtrbkid = st_dataset.qtrbkid;                   

% Build a dummy for born before marriage
outwd = zeros(Nfull,1);                             % Preallocate variable
qtrmar(qtrmar == 0) = NaN;                          % Turn zero quarter into NaN
qtrmar = qtrmar - 1;                                % Index quarters from 0 to 3
yom = yobm + agemar;                                % Back out of year of marriage
yom(qtrbthm > qtrmar) = yom(qtrbthm > qtrmar)+1;
yom(isnan(qtrmar)) = NaN;                           % Input NaN where qtrmar was off
dom_q = yom + (qtrmar/4);                           % Add the quarter information
do1b_q = yobk + ((qtrbkid/4));                      % Get the year + quarter for kid
do1b_q(isnan(qtrmar)) = NaN;                        % Input NaN where qtrmar was off
outwd(dom_q > do1b_q) = 1;                          % Input illegitimate children

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Third: Construct the sexes for the two kids. Back out necessary variables
sexk = st_dataset.sexk;                         
sex2nd = st_dataset.sex2nd;                     
kidcount = st_dataset.kidcount;                 
ageq3rd = ConvertCell(st_dataset.ageq3rd);

% Create the relevant dummy variables
boy1st = (sexk == 0);                               % Dummy for whether first is boy
boy2nd = (sex2nd == 0);                             % Dummy for whether second is boy
boys2 = (sexk == 0)&(sex2nd == 0);                  % Dummy for whether first two are boys
girls2 = (sexk == 1)&(sex2nd == 1);                 % Dummy for whether first two are girls
samesex = (boys2 == 1)|(girls2 == 1);               % Dummy for first two same sex
morekids = (kidcount > 2);                          % Dummy for more than two kids
morea3 = morekids;                                  % If third kid save age
morea3(morekids == 1) = ageq3rd(morekids == 1);     

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fourth: Construct race indicators for father and mother. Back out variables
racem = st_dataset.racem;                       
raced = st_dataset.raced;                       

% Create the relevant variables
blackm = (racem == 2);                      % Mother dummy for black
hispm = (racem == 12);                      % Mother dummy for hispanic
whitem = (racem == 1);                      % Mother dummy for white
othracem = 1 - blackm - hispm - whitem;     % Mother dummy for other

blackd = (raced == 2);                      % Father dummy for black
hispd = (raced == 12);                      % Father dummy for hispanic
whited = (raced == 1);                      % Father dummy for white
othraced = 1 - blackd - hispd - whited;     % Father dummy for other

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fifth: Construct the education variables. Back out what we need
gradem = st_dataset.gradem;
fingradm = st_dataset.fingradm;

% Create the relevant variables
educm = gradem-3;                                   % Mom's grade education
educm((fingradm == 2)|(fingradm ==1)) = gradem((fingradm == 2)|(fingradm ==1))-2;
educm(educm < 0) = 0;
hsgrad = (educm == 12);                             % Dummy for HS
hsormore = (educm >= 12);                           % Dummy for HS or more
moreths = (educm > 12);                             % Dummy for more than HS

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Sixth: Get the ages for father and mother. Back out what we need
agem = st_dataset.agem;
aged = st_dataset.aged;
qtrbthd = st_dataset.qtrbthd;
ageqk = st_dataset.ageqk;
ageq2nd = ConvertCell(st_dataset.ageq2nd);

% Create the relevant variables
yobd = 79 - aged;                               % Year of birth father
yobd(qtrbthd == 0) = 80-aged(qtrbthd == 0);
ageqm = 4*(80-yobm) - qtrbthm - 1;              % Age in quarters mother
ageqd = 4*(80-yobd) - qtrbthd;                  % Age in quarters father
agefstm = floor((ageqm -ageqk)/4);              % Age first born mother
agefstd = floor((ageqd -ageqk)/4);              % Age first born father
age2ndm = floor((ageqm - ageq2nd)/4);           % Age second born mother

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Seventh: Get the labor supply variables. Back out what we need
weeksm = st_dataset.weeksm;
weeksd = st_dataset.weeksd;
hourswd = st_dataset.hoursd;
hourswm = st_dataset.hoursm;
income1d = st_dataset.income1d;
income2d = st_dataset.income2d;
income1m = st_dataset.income1m;
income2m = st_dataset.income2m;
faminc = st_dataset.faminc;

% Create the relevant variables
workedm = zeros(Nfull,1);                       % Indicator for mother worked last year
workedm(weeksm > 0) = 1; 
workedm(isnan(weeksm)) = NaN;   
workedd = zeros(Nfull,1);                       % Indicator for father worked last year
workedd(weeksd > 0) = 1; 
workedd(isnan(weeksd)) = NaN;   
incomed = income1d + max(0,income2d);           % Father's income, same deflation as AE
incomed = incomed*2.099173554;          
incomem = income1m + max(0,income2m);           % Mother's income, same deflation as AE
incomem = incomem*2.099173554;          
faminc = faminc*2.099173554;                    % Family income, same deflation as AE
famincl = log(max(faminc,1));                   % Log family income
nonmomi = faminc - income1m*2.099173554;         % Non-mother's fmaily income
nonmomil = log(max(1,nonmomi));                 % Log of non-mother's family income    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create indicators for the different samples %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First back out some extra variables we'll need
timesmar = st_dataset.timesmar;
marital = st_dataset.marital;
asex = st_dataset.asex;
aage = st_dataset.aage;
aqtrbrth = st_dataset.aqtrbrth;
asex2nd = st_dataset.asex2nd;
aage2nd = st_dataset.aage2nd;

% Follow AE naming to avoid confusion
qobm = qtrbthm;

% Create indicator for the sample
fsample = (agem >= 21)&(agem <=35)&(kidcount>=2)&(ageq2nd>4)&(agefstm >=15)&(asex==0)&(aage==0)&(aqtrbrth==0)&(asex2nd==0)&(aage2nd==0)&(aqtrbrth==0);
msample = (~isnan(aged))&(timesmar == 1)&(marital == 0)&(outwd == 0)&(agefstd>=15)&(agefstm >=15);

% Collect all the variables we'll save following AE
AllVars = table(morekids, boys2, girls2,boy1st, samesex, multi2nd, agem, agefstm, ...
    blackm, hispm, othracem, workedm, weeksm, hourswm, incomem, faminc, nonmomi, ...
    famincl, nonmomil, aged, agefstd, moreths, boy2nd, msample, ...    
    educm, moreths, hsormore, hsgrad, asex, aage, aqtrbrth, asex2nd, aage2nd, ...
    blackd, hispd, othraced, workedd, weeksd, hourswd, incomed, marital, ...
    ageq2nd, ageqk, ageq3rd, morea3, ageqm, yobm, qobm, age2ndm);

% And store only the obsevrations in the fsample indicator
AllVars = AllVars(fsample,:);

save('ProcAE','AllVars');

clear;



 








