function [c, ceq, Gc, Gceq] = f_ATEcon(beta, pos, null)
% f_ATEcon Returns the nonlinear ATE constraint being imposed to compute the
%   test statistic. Takes the value of beta, pos indicating which subgroup ATE
%   is being constraind, and null for the null value. 

% Decompose beta according to the ordering used in main files
% Back out the total number of education bins used
betadim = length(beta);
TotD = betadim/8;              

% Back out the parameters in beta
% Begin by getting the subgroup probabilites
Pa = beta(1:TotD);
Pn = beta(TotD+1:2*TotD);
Pc = 1 - Pa - Pn;

% The averages for the always takers and the never takers
EY1a = beta(2*TotD+1:3*TotD);
EY0a = beta(6*TotD+1:7*TotD);
EY0n = beta(3*TotD+1:4*TotD);
EY1n = beta(7*TotD+1:8*TotD);

% And the constant in LATE equation as well as LATE
BL = beta(5*TotD+1:6*TotD);

% And the corresponding ATEs out of this
ATEa = EY1a-EY0a;
ATEn = EY1n-EY0n;
ATEc = BL;
ATE = Pn.*ATEn + Pa.*ATEa + Pc.*ATEc;

% Set the equality and inequality constraints
c = 0;
ceq = ATE(pos)-null;

% If requested also compute the gradients
if nargout > 2    
    % No inequality constraints
    Gc = zeros(betadim,1);
    
    % Set up the equality constraint derivatives
    % First do it for the probabilities
    dPa = zeros(1,betadim); dPa(pos) = 1;
    dPn = zeros(1,betadim); dPn(TotD+pos) = 1;    
    dPc = -dPa - dPn;
    
    % Then do it for the ATEs
    dATEa = zeros(1,betadim); dATEa(2*TotD+pos) = 1; dATEa(6*TotD+pos) = -1;
    dATEn = zeros(1,betadim); dATEn(3*TotD+pos) = -1; dATEn(7*TotD+pos) = 1;
    dATEc = zeros(1,betadim); dATEc(5*TotD+pos) = 1;
        
    % Finally put it all together 
    Gceq = (ATEn(pos)*dPn + ATEa(pos)*dPa + ATEc(pos)*dPc + Pn(pos)*dATEn + Pa(pos)*dATEa + Pc(pos)*dATEc)';    
end

end