function [out, grad] = f_AggATEobj(beta, Vt, Vp, W0, agg, null)
%f_AggATEobj Is the objective function for the optimization on aggregate ATE inference.
%   It stacks the quadratic terms with the additional moment pinning down the aggreagate
%   ATE, which is a nonlinear functino of the beta.

% Get the ATE from this vector and its gradient
[ATE, dATE] = f_GetATE(beta);

% Create the vector of moments
mom = [Vt- Vp*beta; agg*(ATE-null)];

% The value of the objective function for this problem
out = norm(W0*mom)^2;

% If requested, return the gradient
if nargout > 1    
    % Compute derivative w.r.t. nonlinear moment and stack
    dmom = [-Vp; agg*dATE];
    grad = 2*dmom'*(W0'*W0)*mom;
end

end
